#include <stdio.h>
#include <string.h>

//find the nodes reachable from start
void search(int start, int ** matrix, int * reachable, int directed, 
	    int nodecount)
{
   for (int i=0; i<nodecount; i++)
   {
      if (i==start) continue;
      if (reachable[i]) continue;
      if ( (matrix[start][i]) ||
	   ( (!directed) && (matrix[i][start]) ) )
      {
	 reachable[i]=1;
	 search(i,matrix,reachable,directed,nodecount);
      }
   }
}

void cleanupmatrix(int ** matrix, int nodecount)
{
   for (int i=0; i<nodecount; i++)
      delete[] matrix[i];
   
   delete[] matrix;
}

int main(int argc, char ** argv)
{
  FILE * infile=stdin;
  
  for (;;)
  {
     //read in number of nodes and links
     int nodecount;
     int linkcount;
     fscanf(infile,"%d\n",&nodecount);
     if (nodecount==0)
	break;
     fscanf(infile,"%d\n",&linkcount);
     
     //create adjacency matrix
     int ** matrix=new (int *)[nodecount];
     for (int i=0; i<nodecount; i++)
     {
	matrix[i]=new int[nodecount];
	memset(matrix[i],0,sizeof(int)*nodecount);
     }

     //populate matrix
     for (int i=0; i<linkcount; i++)
     {
	int from,to;
	fscanf(infile,"%d,%d\n",&from,&to);
	matrix[from][to]=1;
     }

     //test for strong connectedness
     int * reachable=new int[nodecount];
     int connected=1;
     for (int i=0; i<nodecount; i++)
     {
	memset(reachable,0,sizeof(int)*nodecount);
	reachable[i]=1;
	search(i,matrix,reachable,1,nodecount);
	for (int j=0; j<nodecount; j++)
	{
	   if (!reachable[j])
	   {
	      connected=0;
	      break;
	   }
	}
	if (!connected) break;
     }
     if (connected) 
     {
	printf("Strongly connected\n");
	cleanupmatrix(matrix,nodecount);
	delete[] reachable;
	continue;
     }

     //test for weak connectedness
     connected=1;
     for (int i=0; i<nodecount; i++)
     {
	memset(reachable,0,sizeof(int)*nodecount);
	reachable[i]=1;
	search(i,matrix,reachable,0,nodecount);
	for (int j=0; j<nodecount; j++)
	{
	   if (!reachable[j])
	   {
	      connected=0;
	      break;
	   }
	}
	if (!connected) break;
     }
     if (connected) 
     {
	printf("Weakly connected\n");
	cleanupmatrix(matrix,nodecount);
	delete[] reachable;
	continue;
     }

     printf("Not connected\n");
     cleanupmatrix(matrix,nodecount);
     delete[] reachable;
  }

  return 0;
}


